@@ -39,8 +39,10 @@ def arg_parser():
 
     args = parser.parse_args()
     config = yaml_parser.parse_config()
+    config_file_path = yaml_parser.get_config_path()
     # print which config file is being used and the path
-    logger.log(message="Using config file: " + config + " from path: " + os.path.dirname(config), log_level="info", to_file=True, to_terminal=True)
+    logger.log(message="Using config file: " + config_file_path, log_level="info", to_file=True, to_terminal=True)
+    logger.log(message="Using config file: " + config_file_path, log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Starting Robin Radar Systems Software Uploader", log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Version: " + _version.__version__, log_level="info", to_file=True, to_terminal=True)
     logger.log(message="Username: " + config['robin_email'], log_level="info", to_file=True, to_terminal=True)
