@@ -34,6 +34,11 @@ def check_and_ask(config):
             elif isinstance(config[key], dict):
                 check_and_ask(config[key])
 
+
+# function for return config file path
+def get_config_path(config_file):
+    return os.path.abspath(config_file)
+
 def parse_config():
     config_files = [
         os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
@@ -53,12 +58,9 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
+                get_config_path(file)
                 # print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
-        # else:
-            # print(f"Config file not found in {cfg_file} directory.")
-            # print(f"Checking next directory...")
-    # if found config file logger which one was found and path
     if not config:
         admin_interface = "https://software-api-admin.robinradar.systems"
         doc_pages = "https://robinradar.atlassian.net/wiki/spaces/DEV/pages/284033095/Software+Deployment+API"
